==> h5vc_1.0.6.tar.gz: h5vc/man/mismatchPlot.Rd <==
\name{mismatchPlot}
\alias{mismatchPlot}

\title{mismatchPlot}
\description{
Plotting function that returns a \code{ggplot2} object representing the
mismatches and coverages of the specified samples in the specified region.
}
\usage{
mismatchPlot( data, sampledata, samples=sampledata$Sample, windowsize, position )
}
\arguments{
  \item{data}{ The data to be plotted. Returned by \code{h5dapply}. Must
  be centered on \code{position} and extend by \code{windowsize} in each
  direction}
  \item{sampledata}{ The sampledata for the cohort represented by
    \code{data}. Returned by \code{getSampleData} }
  \item{samples}{A character vector listing the names of samples to be
    plotted, defaults to all samples as described in \code{sampledata}}
  \item{windowsize}{Size of the window in which to plot on each
    side. The total interval that is plotted will be
    [position-windowsize,position+windowsize]}
  \item{position}{The position at which the plot shall be centered}
}
\details{
  Creates a plot centered on \code{position} using the coverage and
  mismatch counts stored in \code{data}, annotating it with sample
  information provided in the data.frame \code{sampledata} and showing
  all samples listed in \code{sample}.
  
  The plot has the genomic position on the x-axis (centered around \code{position} spanning \code{windowsize} bases up- and downstream). The y-axis encodes values where positive values are on the forward strand and negative values on the reverse. The coverage is shown in grey, deletions in purple and the mismatches in the colors specified in the legend. Note that for each possible mismatch there is an additional color for low-quality counts (coming from the first and last sequencing cycles), so e.g. \code{C} is filled dark red and \code{C_lq} light red.
}
\value{
  A \code{ggplot} object containing the mismatch plot, this can be used
  like any other ggplot object, i.e. additional layers and styles my be
  applied by simply adding them to the plot.
  }
\author{
Paul Pyl
}

\examples{
  # loading library and example data
  library(h5vc)
  tallyFile <- system.file( "extdata", "example.tally.hfs5", package = "h5vcData" )
  sampleData <- getSampleData( tallyFile, "/ExampleStudy/16" )
  position <- 29979628
  windowsize <- 30
  samples <- sampleData$Sample[sampleData$Patient == "Patient8"]
  data <- h5dapply(
    filename = tallyFile,
    group = "/ExampleStudy/16",
    blocksize = windowsize * 3, #choose blocksize larger than range so that all needed data is collected as one block
    names = c("Coverages", "Counts", "Deletions"),
    range = c(position - windowsize, position + windowsize)
  )[[1]]
  p <- mismatchPlot(
    data = data,
    sampledata = sampleData,
    samples = samples,
    windowsize = windowsize,
    position = position
  )
  print(p)
}

==> h5vc_1.4.0.tar.gz: h5vc/man/mismatchPlot.Rd <==
\name{mismatchPlot}
\alias{mismatchPlot}

\title{mismatchPlot}
\description{
Plotting function that returns a \code{ggplot2} object representing the
mismatches and coverages of the specified samples in the specified region.
}
\usage{
mismatchPlot( data, sampledata, samples=sampledata$Sample, windowsize, position, plotReference = TRUE, refHeight = 8 )
}
\arguments{
  \item{data}{ The data to be plotted. Returned by \code{h5dapply}. Must
  be centered on \code{position} and extend by \code{windowsize} in each
  direction}
  \item{sampledata}{ The sampledata for the cohort represented by
    \code{data}. Returned by \code{getSampleData} }
  \item{samples}{A character vector listing the names of samples to be
    plotted, defaults to all samples as described in \code{sampledata}}
  \item{windowsize}{Size of the window in which to plot on each
    side. The total interval that is plotted will be
    [position-windowsize,position+windowsize]}
  \item{position}{The position at which the plot shall be centered}
  \item{plotReference}{This boolean flag specifies if a reference track should be plotted, only takes effect if there is a slot named \code{Reference} in the \code{data} object passed to the function}
  \item{refHeight}{Height of the reference track in coverage units (default of 8 = reference track is as high as 8 reads coverage would be in the plot of a sample.)}
}
\details{
  Creates a plot centered on \code{position} using the coverage and
  mismatch counts stored in \code{data}, annotating it with sample
  information provided in the data.frame \code{sampledata} and showing
  all samples listed in \code{sample}.
  
  The plot has the genomic position on the x-axis (centered around \code{position} spanning \code{windowsize} bases up- and downstream). The y-axis encodes values where positive values are on the forward strand and negative values on the reverse. The coverage is shown in grey, deletions in purple and the mismatches in the colors specified in the legend. Note that for each possible mismatch there is an additional color for low-quality counts (coming from the first and last sequencing cycles), so e.g. \code{C} is filled dark red and \code{C_lq} light red.
}
\value{
  A \code{ggplot} object containing the mismatch plot, this can be used
  like any other ggplot object, i.e. additional layers and styles my be
  applied by simply adding them to the plot.
  }
\author{
Paul Pyl
}

\examples{
  # loading library and example data
  library(h5vc)
  tallyFile <- system.file( "extdata", "example.tally.hfs5", package = "h5vcData" )
  sampleData <- getSampleData( tallyFile, "/ExampleStudy/16" )
  position <- 29979628
  windowsize <- 30
  samples <- sampleData$Sample[sampleData$Patient == "Patient8"]
  data <- h5readBlock(
    filename = tallyFile,
    group = "/ExampleStudy/16",
    names = c("Coverages", "Counts", "Deletions", "Reference"),
    range = c(position - windowsize, position + windowsize)
  )
  p <- mismatchPlot(
    data = data,
    sampledata = sampleData,
    samples = samples,
    windowsize = windowsize,
    position = position
  )
  print(p)
}
